rule win_jasus_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.jasus."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.jasus"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 50 51 6689956cffffff ffd3 83c40c 833d????????00 }
            // n = 6, score = 200
            //   50                   | push                eax
            //   51                   | push                ecx
            //   6689956cffffff       | mov                 word ptr [ebp - 0x94], dx
            //   ffd3                 | call                ebx
            //   83c40c               | add                 esp, 0xc
            //   833d????????00       |                     

        $sequence_1 = { 8955f8 8955e8 8955ec c745f0ffffffff 84c0 7410 8d642400 }
            // n = 7, score = 200
            //   8955f8               | mov                 dword ptr [ebp - 8], edx
            //   8955e8               | mov                 dword ptr [ebp - 0x18], edx
            //   8955ec               | mov                 dword ptr [ebp - 0x14], edx
            //   c745f0ffffffff       | mov                 dword ptr [ebp - 0x10], 0xffffffff
            //   84c0                 | test                al, al
            //   7410                 | je                  0x12
            //   8d642400             | lea                 esp, [esp]

        $sequence_2 = { 84c0 7543 8b45fc 85c0 745a 68???????? }
            // n = 6, score = 200
            //   84c0                 | test                al, al
            //   7543                 | jne                 0x45
            //   8b45fc               | mov                 eax, dword ptr [ebp - 4]
            //   85c0                 | test                eax, eax
            //   745a                 | je                  0x5c
            //   68????????           |                     

        $sequence_3 = { 39580c 0f828d000000 0fb71437 8b4e1a 33c0 89442414 89442418 }
            // n = 7, score = 200
            //   39580c               | cmp                 dword ptr [eax + 0xc], ebx
            //   0f828d000000         | jb                  0x93
            //   0fb71437             | movzx               edx, word ptr [edi + esi]
            //   8b4e1a               | mov                 ecx, dword ptr [esi + 0x1a]
            //   33c0                 | xor                 eax, eax
            //   89442414             | mov                 dword ptr [esp + 0x14], eax
            //   89442418             | mov                 dword ptr [esp + 0x18], eax

        $sequence_4 = { 8945f0 894df8 b801000000 837dec00 745d 85c0 7559 }
            // n = 7, score = 200
            //   8945f0               | mov                 dword ptr [ebp - 0x10], eax
            //   894df8               | mov                 dword ptr [ebp - 8], ecx
            //   b801000000           | mov                 eax, 1
            //   837dec00             | cmp                 dword ptr [ebp - 0x14], 0
            //   745d                 | je                  0x5f
            //   85c0                 | test                eax, eax
            //   7559                 | jne                 0x5b

        $sequence_5 = { 8b1481 40 89560c 8906 8b5e0c 895e14 8a03 }
            // n = 7, score = 200
            //   8b1481               | mov                 edx, dword ptr [ecx + eax*4]
            //   40                   | inc                 eax
            //   89560c               | mov                 dword ptr [esi + 0xc], edx
            //   8906                 | mov                 dword ptr [esi], eax
            //   8b5e0c               | mov                 ebx, dword ptr [esi + 0xc]
            //   895e14               | mov                 dword ptr [esi + 0x14], ebx
            //   8a03                 | mov                 al, byte ptr [ebx]

        $sequence_6 = { 47 897e14 897e70 c686c800000043 c6864b01000043 c74668d0f24100 6a0d }
            // n = 7, score = 200
            //   47                   | inc                 edi
            //   897e14               | mov                 dword ptr [esi + 0x14], edi
            //   897e70               | mov                 dword ptr [esi + 0x70], edi
            //   c686c800000043       | mov                 byte ptr [esi + 0xc8], 0x43
            //   c6864b01000043       | mov                 byte ptr [esi + 0x14b], 0x43
            //   c74668d0f24100       | mov                 dword ptr [esi + 0x68], 0x41f2d0
            //   6a0d                 | push                0xd

        $sequence_7 = { 894de8 8945e4 c745ec00c94100 c745f001010000 c745f41e010000 c745f80f000000 }
            // n = 6, score = 200
            //   894de8               | mov                 dword ptr [ebp - 0x18], ecx
            //   8945e4               | mov                 dword ptr [ebp - 0x1c], eax
            //   c745ec00c94100       | mov                 dword ptr [ebp - 0x14], 0x41c900
            //   c745f001010000       | mov                 dword ptr [ebp - 0x10], 0x101
            //   c745f41e010000       | mov                 dword ptr [ebp - 0xc], 0x11e
            //   c745f80f000000       | mov                 dword ptr [ebp - 8], 0xf

        $sequence_8 = { 8bc6 c1f805 8d1485809d4300 8b0a }
            // n = 4, score = 200
            //   8bc6                 | mov                 eax, esi
            //   c1f805               | sar                 eax, 5
            //   8d1485809d4300       | lea                 edx, [eax*4 + 0x439d80]
            //   8b0a                 | mov                 ecx, dword ptr [edx]

        $sequence_9 = { e8???????? 0fb71d???????? 8945fc 0fb705???????? 56 68???????? e8???????? }
            // n = 7, score = 200
            //   e8????????           |                     
            //   0fb71d????????       |                     
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   0fb705????????       |                     
            //   56                   | push                esi
            //   68????????           |                     
            //   e8????????           |                     

    condition:
        7 of them and filesize < 507904
}